@@ -1,48 +1,53 @@
 #' Fortify method for classes from the sp package.
-#' 
-#' To figure out the correct variable name for region, inspect 
+#'
+#' To figure out the correct variable name for region, inspect
 #' \code{as.data.frame(model)}.
-#' 
-#' @S3method fortify SpatialPolygons
-#' @S3method fortify SpatialPolygonsDataFrame
-#' @S3method fortify Polygons
-#' @S3method fortify Polygon
-#' @S3method fortify SpatialLinesDataFrame
-#' @S3method fortify Lines
-#' @S3method fortify Line
+#'
 #' @param model \code{SpatialPolygonsDataFrame} to convert into a dataframe.
 #' @param data not used by this method
 #' @param region name of variable used to split up regions
 #' @param ... not used by this method
 #' @name fortify.sp
+#' @examples
+#' if (require("maptools")) {
+#'  sids <- system.file("shapes/sids.shp", package="maptools")
+#'  nc1 <- readShapePoly(sids,
+#'    proj4string = CRS("+proj=longlat +datum=NAD27"))
+#'  nc1_df <- fortify(nc1)
+#' }
 NULL
 
+#' @rdname fortify.sp
+#' @export
+#' @method fortify SpatialPolygonsDataFrame
 fortify.SpatialPolygonsDataFrame <- function(model, data, region = NULL, ...) {
   attr <- as.data.frame(model)
-  # If not specified, split into regions based on first variable in attributes
+  # If not specified, split into regions based on polygons
   if (is.null(region)) {
-    region <- names(attr)[1]
-    message("Using ", region, " to define regions.")
+    coords <- ldply(model@polygons,fortify)
+    message("Regions defined for each Polygons")
+  } else {
+    cp <- sp::polygons(model)
+    try_require("maptools")
+
+    # Union together all polygons that make up a region
+    unioned <- unionSpatialPolygons(cp, attr[, region])
+    coords <- fortify(unioned)
+    coords$order <- 1:nrow(coords)
   }
-  
-  # Figure out how polygons should be split up into the region of interest
-  
-  polys <- split(as.numeric(row.names(attr)), addNA(attr[, region], TRUE))
-  cp <- polygons(model)
-  
-  # Union together all polygons that make up a region
-  try_require(c("gpclib", "maptools"))
-  unioned <- unionSpatialPolygons(cp, invert(polys))
-  
-  coords <- fortify(unioned)
-  coords$order <- 1:nrow(coords)
   coords
 }
 
+#' @rdname fortify.sp
+#' @export
+#' @method fortify SpatialPolygons
 fortify.SpatialPolygons <- function(model, data, ...) {
   ldply(model@polygons, fortify)
 }
 
+#' @rdname fortify.sp
+#' @export
+#' @method fortify Polygons
 fortify.Polygons <- function(model, data, ...) {
   subpolys <- model@Polygons
   pieces <- ldply(seq_along(subpolys), function(i) {
@@ -50,7 +55,7 @@ fortify.Polygons <- function(model, data, ...) {
     df$piece <- i
     df
   })
-  
+
   within(pieces,{
     order <- 1:nrow(pieces)
     id <- model@ID
@@ -59,6 +64,9 @@ fortify.Polygons <- function(model, data, ...) {
   })
 }
 
+#' @rdname fortify.sp
+#' @export
+#' @method fortify Polygon
 fortify.Polygon <- function(model, data, ...) {
   df <- as.data.frame(model@coords)
   names(df) <- c("long", "lat")
@@ -67,10 +75,16 @@ fortify.Polygon <- function(model, data, ...) {
   df
 }
 
+#' @rdname fortify.sp
+#' @export
+#' @method fortify SpatialLinesDataFrame
 fortify.SpatialLinesDataFrame <- function(model, data, ...) {
   ldply(model@lines, fortify)
 }
 
+#' @rdname fortify.sp
+#' @export
+#' @method fortify Lines
 fortify.Lines <- function(model, data, ...) {
   lines <- model@Lines
   pieces <- ldply(seq_along(lines), function(i) {
@@ -78,7 +92,7 @@ fortify.Lines <- function(model, data, ...) {
     df$piece <- i
     df
   })
-  
+
   within(pieces,{
     order <- 1:nrow(pieces)
     id <- model@ID
@@ -87,9 +101,12 @@ fortify.Lines <- function(model, data, ...) {
   })
 }
 
+#' @rdname fortify.sp
+#' @export
+#' @method fortify Line
 fortify.Line <- function(model, data, ...) {
   df <- as.data.frame(model@coords)
   names(df) <- c("long", "lat")
   df$order <- 1:nrow(df)
-  df  
+  df
 }
