@@ -1,5 +1,5 @@
 #' Line, vertical.
-#' 
+#'
 #' This geom allows you to annotate the plot with vertical lines (see
 #' \code{\link{geom_hline}} and \code{\link{geom_abline}} for other types of
 #' lines.
@@ -10,6 +10,9 @@
 #' intercept for each panel using a data.frame.  See the examples for the
 #' differences.
 #'
+#' @section Aesthetics:
+#' \Sexpr[results=rd,stage=build]{ggplot2:::rd_aesthetics("geom", "vline")}
+#'
 #' @param show_guide should a legend be drawn? (defaults to \code{FALSE})
 #' @inheritParams geom_point
 #' @seealso
@@ -24,21 +27,21 @@
 #' p + geom_vline(xintercept = 1:5)
 #' p + geom_vline(xintercept = 1:5, colour="green", linetype = "longdash")
 #' p + geom_vline(aes(xintercept = wt))
-#' 
+#'
 #' # With coordinate transforms
 #' p + geom_vline(aes(xintercept = wt)) + coord_equal()
 #' p + geom_vline(aes(xintercept = wt)) + coord_flip()
 #' p + geom_vline(aes(xintercept = wt)) + coord_polar()
-#' 
+#'
 #' p2 <- p + aes(colour = factor(cyl))
 #' p2 + geom_vline(xintercept = 15)
 #'
-#' # To display different lines in different facets, you need to 
+#' # To display different lines in different facets, you need to
 #' # create a data frame.
-#' p <- qplot(mpg, wt, data=mtcars, facets = vs ~ am)   
-#' vline.data <- data.frame(z = c(15, 20, 25, 30), vs = c(0, 0, 1, 1), am = c(0, 1, 0, 1)) 
+#' p <- qplot(mpg, wt, data=mtcars, facets = vs ~ am)
+#' vline.data <- data.frame(z = c(15, 20, 25, 30), vs = c(0, 0, 1, 1), am = c(0, 1, 0, 1))
 #' p + geom_vline(aes(xintercept = z), vline.data)
-geom_vline <- function (mapping = NULL, data = NULL, stat = "vline", position = "identity", show_guide = FALSE, ...) { 
+geom_vline <- function (mapping = NULL, data = NULL, stat = "vline", position = "identity", show_guide = FALSE, ...) {
   GeomVline$new(mapping = mapping, data = data, stat = stat, position = position, show_guide = show_guide, ...)
 }
 
@@ -51,21 +54,20 @@ GeomVline <- proto(Geom, {
       xintercept <- NULL
       mapping <- aes_all(names(data))
     }
-    .super$new(., data = data, mapping = mapping, inherit.aes = FALSE, 
+    .super$new(., data = data, mapping = mapping, inherit.aes = FALSE,
       xintercept = xintercept, ...)
   }
-  
+
   draw <- function(., data, scales, coordinates, ...) {
     ranges <- coord_range(coordinates, scales)
 
     data$y    <- ranges$y[1]
     data$yend <- ranges$y[2]
-    
+
     GeomSegment$draw(unique(data), scales, coordinates)
   }
 
-  
-  icon <- function(.) linesGrob(c(0.5, 0.5), c(0, 1))
+
   default_stat <- function(.) StatVline
   default_aes <- function(.) aes(colour="black", size=0.5, linetype=1, alpha = NA)
   guide_geom <- function(.) "vline"
@@ -73,7 +75,7 @@ GeomVline <- proto(Geom, {
   draw_legend <- function(., data, ...) {
     data <- aesdefaults(data, .$default_aes(), list(...))
 
-    with(data, 
+    with(data,
       ggname(.$my_name(), segmentsGrob(0.5, 0, 0.5, 1, default.units="npc",
       gp=gpar(col=alpha(colour, alpha), lwd=size * .pt, lty=linetype, lineend="butt")))
     )
