@@ -2,12 +2,12 @@
 #'
 #' Legend type guide shows key (i.e., geoms) mapped onto values.
 #' Legend guides for various scales are integrated if possible.
-#' 
+#'
 #' Guides can be specified in each scale or in \code{\link{guides}}.
 #' \code{guide="legend"} in scale is syntactic sugar for
 #' \code{guide=guide_legend()}. As for how to specify the guide for each
 #' scales in more detail, see \code{\link{guides}}.
-#' 
+#'
 #' @param title A character string or expression indicating a title of guide.
 #'   If \code{NULL}, the title is not shown. By default
 #'   (\code{\link{waiver}}), the name of the scale object or tha name
@@ -16,8 +16,8 @@
 #'   title. One of "top" (default for a vertical guide), "bottom", "left"
 #'  (default for a horizontal guide), or "right."
 #' @param title.theme A theme object for rendering the title text. Usually the
-#'   object of \code{\link{theme_text}} is expected. By default, the theme is
-#'   specified by \code{legend.title} in \code{\link{opts}} or theme.
+#'   object of \code{\link{element_text}} is expected. By default, the theme is
+#'   specified by \code{legend.title} in \code{\link{theme}} or theme.
 #' @param title.hjust A number specifying horizontal justification of the
 #'   title text.
 #' @param title.vjust A number specifying vertical justification of the title
@@ -28,18 +28,18 @@
 #'   label. One of "top", "bottom" (default for horizontal guide), "left", or
 #'   "right" (default for vertical gudie).
 #' @param label.theme A theme object for rendering the label text. Usually the
-#'   object of \code{\link{theme_text}} is expected. By default, the theme is
-#'   specified by \code{legend.text} in \code{\link{opts}} or theme.
+#'   object of \code{\link{element_text}} is expected. By default, the theme is
+#'   specified by \code{legend.text} in \code{\link{theme}} or theme.
 #' @param label.hjust A numeric specifying horizontal justification of the
 #'   label text.
 #' @param label.vjust A numeric specifying vertical justification of the label
 #'   text.
 #' @param keywidth A numeric or a unit object specifying the width of the
 #'   legend key. Default value is \code{legend.key.width} or
-#'   \code{legend.key.size} in \code{\link{opts}} or theme.
+#'   \code{legend.key.size} in \code{\link{theme}} or theme.
 #' @param keyheight A numeric or a unit object specifying the height of the
 #'   legend key. Default value is \code{legend.key.height} or
-#'   \code{legend.key.size} in \code{\link{opts}} or theme.
+#'   \code{legend.key.size} in \code{\link{theme}} or theme.
 #' @param direction  A character string indicating the direction of the guide.
 #'   One of "horizontal" or "vertical."
 #' @param default.unit A character string indicating unit for \code{keywidth}
@@ -51,6 +51,9 @@
 #' @param byrow logical. If \code{FALSE} (the default) the legend-matrix is
 #'   filled by columns, otherwise the legend-matrix is filled by rows.
 #' @param reverse logical. If \code{TRUE} the order of legends is reversed.
+#' @param order positive integer less that 99 that specify the order of
+#'   this guide in the multiple guides. If 0 (default), the order is determined
+#'   by a secret algorithm.
 #' @param ... ignored.
 #' @return A guide object
 #' @export
@@ -59,7 +62,7 @@
 #' \donttest{
 #' library(reshape2) # for melt
 #' df <- melt(outer(1:4, 1:4), varnames = c("X1", "X2"))
-#' 
+#'
 #' p1 <- ggplot(df, aes(X1, X2)) + geom_tile(aes(fill = value))
 #' p2 <- p1 + geom_point(aes(size = value))
 #'
@@ -68,55 +71,55 @@
 #' p1 + scale_fill_continuous(guide = guide_legend())
 #'
 #' # Guide title
-#' 
+#'
 #' p1 + scale_fill_continuous(guide = guide_legend(title = "V")) # title text
 #' p1 + scale_fill_continuous(name = "V") # same
 #' p1 + scale_fill_continuous(guide = guide_legend(title = NULL)) # no title
-#' 
+#'
 #' # Control styles
-#' 
+#'
 #' # key size
 #' p1 + guides(fill = guide_legend(keywidth = 3, keyheight = 1))
-#' 
+#'
 #' # title position
 #' p1 + guides(fill = guide_legend(title = "LEFT", title.position = "left"))
-#' 
-#' # title text styles via theme_text
+#'
+#' # title text styles via element_text
 #' p1 + guides(fill = guide_legend(
-#'   title.theme = theme_text(size=15, face="italic", col="red", angle=45)))
-#' 
+#'   title.theme = element_text(size=15, face="italic", colour = "red", angle = 45)))
+#'
 #' # label position
 #' p1 + guides(fill = guide_legend(label.position = "bottom"))
-#' 
+#'
 #' # label styles
-#' p1 + scale_fill_continuous(breaks = c(5, 10, 15), 
-#'   labels = paste("long", c(5, 10, 15)), 
+#' p1 + scale_fill_continuous(breaks = c(5, 10, 15),
+#'   labels = paste("long", c(5, 10, 15)),
 #'   guide = guide_legend(direction = "horizontal", title.position = "top",
 #'     label.position="bottom", label.hjust = 0.5, label.vjust = 0.5,
-#'     label.theme = theme_text(angle = 90)))
-#' 
+#'     label.theme = element_text(angle = 90)))
+#'
 #' # Set aesthetic of legend key
-#' 
+#'
 #' # very low alpha value make it difficult to see legend key
-#' p3 <- qplot(carat, price, data = diamonds, colour = color, 
+#' p3 <- qplot(carat, price, data = diamonds, colour = color,
 #'   alpha = I(1/100))
 #' p3
-#' 
+#'
 #' # override.aes overwrites the alpha
 #' p3 + guides(colour = guide_legend(override.aes = list(alpha = 1)))
-#' 
+#'
 #' # multiple row/col legends
 #' p <- qplot(1:20, 1:20, colour = letters[1:20])
 #' p + guides(col = guide_legend(nrow = 8))
 #' p + guides(col = guide_legend(ncol = 8))
 #' p + guides(col = guide_legend(nrow = 8, byrow = TRUE))
 #' p + guides(col = guide_legend(ncol = 8, byrow = TRUE))
-#' 
+#'
 #' # reversed order legend
 #' p + guides(col = guide_legend(reverse = TRUE))
 #' }
 guide_legend <- function(
-                         
+
   #　title
   title = waiver(),
   title.position = NULL,
@@ -130,7 +133,7 @@ guide_legend <- function(
   label.theme = NULL,
   label.hjust = NULL,
   label.vjust = NULL,
-                         
+
   # key
   keywidth = NULL,
   keyheight = NULL,
@@ -143,12 +146,13 @@ guide_legend <- function(
   ncol = NULL,
   byrow = FALSE,
   reverse = FALSE,
-                         
+  order = 0,
+
   ...) {
-  
+
   if (!is.null(keywidth) && !is.unit(keywidth)) keywidth <- unit(keywidth, default.unit)
   if (!is.null(keyheight) && !is.unit(keyheight)) keyheight <- unit(keyheight, default.unit)
-  
+
   structure(list(
     #　title
     title = title,
@@ -156,7 +160,7 @@ guide_legend <- function(
     title.theme = title.theme,
     title.hjust = title.hjust,
     title.vjust = title.vjust,
-                 
+
     # label
     label = label,
     label.position = label.position,
@@ -176,7 +180,8 @@ guide_legend <- function(
     ncol = ncol,
     byrow = byrow,
     reverse = reverse,
-                 
+    order = order,
+
     # parameter
     available_aes = c("any"),
 
@@ -184,6 +189,7 @@ guide_legend <- function(
     class=c("guide", "legend"))
 }
 
+#' @export
 guide_train.legend <- function(guide, scale) {
   breaks <- scale_breaks(scale)
   key <- data.frame(
@@ -205,17 +211,18 @@ guide_train.legend <- function(guide, scale) {
   } else {
     key <- key[!is.na(breaks), , drop = FALSE]
   }
-  
+
   if (empty(key) || all(is.na(breaks))) return(NULL)
   names(key) <- c(scale$aesthetics[1], ".label")
 
   if (guide$reverse) key <- key[nrow(key):1, ]
-  
+
   guide$key <- key
   guide$hash <- with(guide, digest(list(title, key$.label, direction, name)))
   guide
 }
 
+#' @export
 guide_merge.legend <- function(guide, new_guide) {
   guide$key <- merge(guide$key, new_guide$key, sort=FALSE)
   guide$override.aes <- c(guide$override.aes, new_guide$override.aes)
@@ -224,6 +231,7 @@ guide_merge.legend <- function(guide, new_guide) {
   guide
 }
 
+#' @export
 guide_geom.legend <- function(guide, layers, default_mapping) {
 
   # TODO: how to deal with same geoms of multiple layers.
@@ -232,7 +240,7 @@ guide_geom.legend <- function(guide, layers, default_mapping) {
   # but probably it is better to sensitive to that and generate only one geom like this:
   #
   # geoms <- unique(sapply(layers, function(layer) if (is.na(layer$legend) || layer$legend) layer$geom$guide_geom() else NULL))
-  # 
+  #
   # but in this case, some conflicts occurs, e.g.,
   #
   # d <- data.frame(x=1:5, y=1:5, v=factor(1:5))
@@ -240,18 +248,18 @@ guide_geom.legend <- function(guide, layers, default_mapping) {
   #
   # geom_line generate path geom with red and geom_rug generate it with blue.
   # how to deal with them ?
-  
+
   # arrange common data for vertical and horizontal guide
   guide$geoms <- llply(layers, function(layer) {
     all <- names(c(layer$mapping, default_mapping, layer$stat$default_aes()))
     geom <- c(layer$geom$required_aes, names(layer$geom$default_aes()))
     matched <- intersect(intersect(all, geom), names(guide$key))
     matched <- setdiff(matched, names(layer$geom_params))
-    data <- 
+    data <-
       if (length(matched) > 0) {
         # This layer contributes to the legend
         if (is.na(layer$show_guide) || layer$show_guide) {
-          # Default is to include it 
+          # Default is to include it
           layer$use_defaults(guide$key[matched])
         } else {
           NULL
@@ -266,7 +274,7 @@ guide_geom.legend <- function(guide, layers, default_mapping) {
         }
       }
     if (is.null(data)) return(NULL)
-    
+
     # override.aes in guide_legend manually changes the geom
     for (aes in intersect(names(guide$override.aes), names(data))) data[[aes]] <- guide$override.aes[[aes]]
 
@@ -284,12 +292,14 @@ guide_geom.legend <- function(guide, layers, default_mapping) {
   guide
 }
 
+#' @export
 guide_gengrob.legend <- function(guide, theme) {
 
   # default setting
   label.position <- guide$label.position %||% "right"
-  if (!label.position %in% c("top", "bottom", "left", "right")) stop("label position \"", label.position, "\" is invalid")
-  
+  if (!label.position %in% c("top", "bottom", "left", "right"))
+    stop("label position \"", label.position, "\" is invalid")
+
   nbreak <- nrow(guide$key)
 
   # gap between keys etc
@@ -297,16 +307,18 @@ guide_gengrob.legend <- function(guide, theme) {
   vgap <- hgap
 
   # title
-  title.theme <- guide$title.theme %||% theme$legend.title
+  title.theme <- guide$title.theme %||% calc_element("legend.title", theme)
   title.hjust <- title.x <- guide$title.hjust %||% theme$legend.title.align %||% 0
   title.vjust <- title.y <- guide$title.vjust %||% 0.5
-  
+
   grob.title <- {
     if (is.null(guide$title))
       zeroGrob()
-    else 
-      title.theme(label=guide$title, name=grobName(NULL, "guide.title"),
-                  hjust = title.hjust, vjust = title.vjust, x = title.x, y = title.y)
+    else {
+      g <- element_grob(title.theme, label=guide$title,
+        hjust = title.hjust, vjust = title.vjust, x = title.x, y = title.y)
+      ggname("guide.title", g)
+    }
   }
 
   title_width <- convertWidth(grobWidth(grob.title), "mm")
@@ -319,19 +331,26 @@ guide_gengrob.legend <- function(guide, theme) {
   #
   # label.theme in param of guide_legend() > theme$legend.text.align > default
   # hjust/vjust in theme$legend.text and label.theme are ignored.
-  # 
+  #
   # Default:
   #   If label includes expression, the label is right-alignd (hjust = 0). Ohterwise, left-aligned (x = 1, hjust = 1).
   #   Vertical adjustment is always mid-alined (vjust = 0.5).
-  label.theme <- guide$label.theme %||% theme$legend.text
+  label.theme <- guide$label.theme %||% calc_element("legend.text", theme)
   grob.labels <- {
     if (!guide$label)
       zeroGrob()
     else {
-      hjust <- x <- guide$label.hjust %||% theme$legend.text.align %||% if (any(is.expression(guide$key$.label))) 1 else 0
+      hjust <- x <- guide$label.hjust %||% theme$legend.text.align %||%
+        if (any(is.expression(guide$key$.label))) 1 else 0
       vjust <- y <- guide$label.vjust %||% 0.5
-      lapply(guide$key$.label, function(label) label.theme(label=label, name=grobName(NULL, "guide.label"),
-                                                           x = x, y = y, hjust = hjust, vjust = vjust))
+
+      lapply(guide$key$.label,
+        function(label, ...) {
+          g <- element_grob(element = label.theme, label = label,
+            x = x, y = y, hjust = hjust, vjust = vjust)
+          ggname("guide.label", g)
+        }
+      )
     }
   }
 
@@ -344,14 +363,14 @@ guide_gengrob.legend <- function(guide, theme) {
 
   key_width <- convertWidth(guide$keywidth %||% theme$legend.key.width %||% theme$legend.key.size, "mm")
   key_height <- convertHeight(guide$keyheight %||% theme$legend.key.height %||% theme$legend.key.size, "mm")
-  
+
   key_width.c <- c(key_width)
   key_height.c <- c(key_height)
 
   key_size_mat <- do.call("cbind", llply(guide$geoms, function(g) g$data$size))
   key_sizes <- if (is.null(key_size_mat)) rep(0, nbreak) else apply(key_size_mat, 1, max)
 
-  if (!is.null(guide$nrow) && !is.null(guide$ncol) && guide$nrow * guide$ncol < nbreak) 
+  if (!is.null(guide$nrow) && !is.null(guide$ncol) && guide$nrow * guide$ncol < nbreak)
     stop("nrow x ncol need to be larger than the number of breaks")
   legend.nrow <- guide$nrow %||%
     if (!is.null(guide$ncol)) ceiling(nbreak/guide$ncol)
@@ -364,7 +383,7 @@ guide_gengrob.legend <- function(guide, theme) {
 
   key_widths.c <- pmax(key_width.c, apply(key_sizes, 2, max))
   key_heights.c <-pmax(key_height.c, apply(key_sizes, 1, max))
-  
+
   label_widths.c <- apply(matrix(c(label_widths.c, rep(0, legend.nrow * legend.ncol - nbreak)),
                                  legend.nrow, legend.ncol, byrow = guide$byrow),
                           2, max)
@@ -398,7 +417,7 @@ guide_gengrob.legend <- function(guide, theme) {
         kl_widths <- head(interleave(key_widths.c, hgap/2, label_widths.c, hgap/2), -1)
         kl_heights <- head(interleave(pmax(label_heights.c, key_heights.c), vgap/2), -1)
         vps <- transform(vps, key.row = R*2-1, key.col = C*4-3, label.row = R*2-1, label.col = C*4-1)
-        })      
+        })
   } else {
     switch(label.position,
       "top" = {
@@ -452,7 +471,7 @@ guide_gengrob.legend <- function(guide, theme) {
 
   # grob for key
   grob.keys <- list()
-  
+
   for (i in 1:nbreak) {
 
     # layout position
@@ -460,7 +479,7 @@ guide_gengrob.legend <- function(guide, theme) {
     pos.col <- vps$key.col[i]
 
     # bg. of key
-    grob.keys[[length(grob.keys)+1]] <- theme_render(theme, "legend.key")
+    grob.keys[[length(grob.keys)+1]] <- element_render(theme, "legend.key")
 
     # overlay geoms
     for(geom in guide$geoms)
@@ -468,7 +487,7 @@ guide_gengrob.legend <- function(guide, theme) {
   }
 
   # background
-  grob.background <- theme_render(theme, "legend.background")
+  grob.background <- element_render(theme, "legend.background")
 
   ngeom <- length(guide$geoms) + 1
   kcols <- rep(vps$key.col, each =  ngeom)
@@ -479,14 +498,23 @@ guide_gengrob.legend <- function(guide, theme) {
   widths <- c(padding, widths, padding)
   heights <- c(padding, heights, padding)
 
-  lay <- data.frame(l = 1 + c(0,                   min(vps.title.col), kcols, vps$label.col),
-                    t = 1 + c(0,                   min(vps.title.row), krows, vps$label.row),
-                    r = 1 + c(length(widths) - 1,  max(vps.title.col), kcols, vps$label.col),
-                    b = 1 + c(length(heights) - 1, max(vps.title.row), krows, vps$label.row),
-                    name = c("background", "title",
-                      paste("key", krows, kcols, c("bg", seq(ngeom-1)), sep = "-"),
-                      paste("label", vps$label.row, vps$label.col, sep = "-")),
-                    clip = FALSE)
+  # Create the gtable for the legend
+  gt <- gtable(widths = unit(widths, "mm"), heights = unit(heights, "mm"))
+  gt <- gtable_add_grob(gt, grob.background, name = "background", clip = "off",
+    t = 1, r = -1, b = -1, l = 1)
+  gt <- gtable_add_grob(gt, grob.title, name = "title", clip = "off",
+    t = 1 + min(vps.title.row), r = 1 + max(vps.title.col),
+    b = 1 + max(vps.title.row), l = 1 + min(vps.title.col))
+  gt <- gtable_add_grob(gt, grob.keys,
+    name = paste("key", krows, kcols, c("bg", seq(ngeom-1)), sep = "-"), clip = "off",
+    t = 1 + krows, r = 1 + kcols,
+    b = 1 + krows, l = 1 + kcols)
+  gt <- gtable_add_grob(gt, grob.labels,
+    name = paste("label", vps$label.row, vps$label.col, sep = "-"), clip = "off",
+    t = 1 + vps$label.row, r = 1 + vps$label.col,
+    b = 1 + vps$label.row, l = 1 + vps$label.col)
 
-  gtable(c(list(grob.background, grob.title), grob.keys, grob.labels), lay, unit(widths, "mm"), unit(heights, "mm"))
+  gt
 }
+
+globalVariables(c("R", "key.row", "key.col", "label.row", "label.col"))
