@@ -1,9 +1,56 @@
-#' A theme with grey background and white gridlines.
+#' ggplot2 themes
+#'
+#' Themes set the general aspect of the plot such as the colour of the
+#' background, gridlines, the size and colour of fonts.
 #'
 #' @param base_size base font size
 #' @param base_family base font family
-#' @aliases theme_gray theme_grey
-#' @export theme_gray theme_grey
+#'
+#' @details \describe{
+#'
+#' \item{\code{theme_gray}}{
+#' The signature ggplot2 theme with a grey background and white gridlines,
+#' designed to put the data forward yet make comparisons easy.}
+#'
+#' \item{\code{theme_bw}}{
+#' The classic dark-on-light ggplot2 theme. May work better for presentations
+#' displayed with a projector.}
+#'
+#' \item{\code{theme_linedraw}}{
+#' A theme with only black lines of various widths on white backgrounds,
+#' reminiscent of a line drawings. Serves a purpose similar to \code{theme_bw}.
+#' Note that this theme has some very thin lines (<< 1 pt) which some journals
+#' may refuse.}
+#'
+#' \item{\code{theme_light}}{
+#' A theme similar to \code{theme_linedraw} but with light grey lines and axes,
+#' to direct more attention towards the data.}
+#'
+#' \item{\code{theme_minimal}}{
+#' A minimalistic theme with no background annotations.}
+#'
+#' \item{\code{theme_classic}}{
+#' A classic-looking theme, with x and y axis lines and no gridlines.}
+#'
+#' }
+#'
+#' @examples
+#' p <- ggplot(mtcars) + geom_point(aes(x = wt, y = mpg,
+#'      colour=factor(gear))) + facet_wrap(~am)
+#'
+#' p
+#' p + theme_gray()
+#' p + theme_bw()
+#' p + theme_linedraw()
+#' p + theme_light()
+#' p + theme_minimal()
+#' p + theme_classic()
+#'
+#' @name ggtheme
+NULL
+
+#' @export
+#' @rdname ggtheme
 theme_grey <- function(base_size = 12, base_family = "") {
   theme(
     # Elements in this first block aren't used directly, but are inherited
@@ -46,6 +93,8 @@ theme_grey <- function(base_size = 12, base_family = "") {
     panel.grid.major =   element_line(colour = "white"),
     panel.grid.minor =   element_line(colour = "grey95", size = 0.25),
     panel.margin =       unit(0.25, "lines"),
+    panel.margin.x =     NULL,
+    panel.margin.y =     NULL,
 
     strip.background =   element_rect(fill = "grey80", colour = NA),
     strip.text.x =       element_text(),
@@ -58,14 +107,12 @@ theme_grey <- function(base_size = 12, base_family = "") {
     complete = TRUE
   )
 }
+#' @export
+#' @rdname ggtheme
 theme_gray <- theme_grey
 
-
-#' A theme with white background and black gridlines.
-#'
-#' @param base_size base font size
-#' @param base_family base font family
 #' @export
+#' @rdname ggtheme
 theme_bw <- function(base_size = 12, base_family = "") {
   # Starts with theme_grey and then modify some parts
   theme_grey(base_size = base_size, base_family = base_family) %+replace%
@@ -77,16 +124,50 @@ theme_bw <- function(base_size = 12, base_family = "") {
       panel.border      = element_rect(fill = NA, colour = "grey50"),
       panel.grid.major  = element_line(colour = "grey90", size = 0.2),
       panel.grid.minor  = element_line(colour = "grey98", size = 0.5),
-      strip.background  = element_rect(fill = "grey80", colour = "grey50"),
-      strip.background  = element_rect(fill = "grey80", colour = "grey50")
+      strip.background  = element_rect(fill = "grey80", colour = "grey50", size = 0.2)
     )
 }
 
-#' A minimalistic theme with no background annotations.
-#'
-#' @param base_size base font size
-#' @param base_family base font family
 #' @export
+#' @rdname ggtheme
+theme_linedraw <- function(base_size = 12, base_family = "") {
+  # Starts with theme_grey and then modify some parts
+  theme_grey(base_size = base_size, base_family = base_family) %+replace%
+    theme(
+      axis.text         = element_text(colour = "black", size = rel(0.8)),
+      axis.ticks        = element_line(colour = "black", size = 0.25),
+      legend.key        = element_rect(colour = "black", size = 0.25),
+      panel.background  = element_rect(fill = "white", colour = NA),
+      panel.border      = element_rect(fill = NA, colour = "black", size = 0.5),
+      panel.grid.major  = element_line(colour = "black", size = 0.05),
+      panel.grid.minor  = element_line(colour = "black", size = 0.01),
+      strip.background  = element_rect(fill = "black", colour = NA),
+      strip.text.x      = element_text(colour = "white"),
+      strip.text.y      = element_text(colour = "white", angle = -90)
+    )
+}
+
+#' @export
+#' @rdname ggtheme
+theme_light <- function(base_size = 12, base_family = "") {
+  # Starts with theme_grey and then modify some parts
+  theme_grey(base_size = base_size, base_family = base_family) %+replace%
+    theme(
+      axis.ticks        = element_line(colour = "grey70", size = 0.25),
+      legend.key        = element_rect(fill = "white", colour = "grey50", size = 0.25),
+      panel.background  = element_rect(fill = "white", colour = NA),
+      panel.border      = element_rect(fill = NA, colour = "grey70", size = 0.5),
+      panel.grid.major  = element_line(colour = "grey85", size = 0.25),
+      panel.grid.minor  = element_line(colour = "grey93", size = 0.125),
+      strip.background  = element_rect(fill = "grey70", colour = NA),
+      strip.text.x      = element_text(colour = "white"),
+      strip.text.y      = element_text(colour = "white", angle = -90)
+    )
+
+}
+
+#' @export
+#' @rdname ggtheme
 theme_minimal <- function(base_size = 12, base_family = "") {
   # Starts with theme_bw and then modify some parts
   theme_bw(base_size = base_size, base_family = base_family) %+replace%
@@ -100,17 +181,16 @@ theme_minimal <- function(base_size = 12, base_family = "") {
     )
 }
 
-#' A classic-looking theme, with x and y axis lines and no gridlines.
-#'
-#' @param base_size base font size
-#' @param base_family base font family
 #' @export
+#' @rdname ggtheme
 theme_classic <- function(base_size = 12, base_family = ""){
   theme_bw(base_size = base_size, base_family = base_family) %+replace%
     theme(
       panel.border     = element_blank(),
       axis.line        = element_line(colour = "black"),
       panel.grid.major = element_blank(),
-      panel.grid.minor = element_blank()
+      panel.grid.minor = element_blank(),
+      strip.background = element_rect(colour = "black", size = 0.5),
+      legend.key       = element_blank()
     )
 }
